darkhistory.physics.nHe — DarkHistory documentation

- Repository
- DarkHistory documentation
- DarkHistory
- darkhistory
- darkhistory.physics

- index
- modules
- next
- previous

# darkhistory.physics.nHe

`darkhistory.physics.` `nHe` = 1.4980406903646495e-08

  Atomic helium number density in cm-3.

#### Previous topic

darkhistory.physics.nH

#### Next topic

darkhistory.physics.nA

### This Page

Show Source

- © Copyright 2019, Hongwan Liu, Gregory Ridgway and Tracy Slatyer.
- Created using Sphinx 1.8.5.